@@ -35,18 +35,23 @@ class Element(BaseModel):
             except AttributeError:
                 pass
 
-    def find_links(self):
+    def find_urls(self):
         for child in self.children:
-            if re.match(r"http", child.text):
-                yield {"link" if child.tag_name is None else child.tag_name: child.text}
+            if re.match("http", child.text):
+                yield child.text
             for attr in child.attributes:
-                if re.match(r"http", attr.value):
-                    yield {child.tag_name: attr.value}
-            yield from child.find_links()
+                if re.match("http", attr.value):
+                    yield attr.value
+            yield from child.find_urls()
 
-    @property
-    def next_text(self):
-        return self.find(None).text
+    def find_text(self):
+        for child in self.children:
+            if not child.tag_name:
+                yield child.text.strip()
+            yield from child.find_text()
 
     def __str__(self):
         return f"<{self.tag_name}>"
+
+    def __repr__(self):
+        return f"<{self.tag_name}>"
